@@ -1,11 +1,10 @@
 package Sys::Info::Driver::Unknown::Device::CPU;
+$Sys::Info::Driver::Unknown::Device::CPU::VERSION = '0.79';
 use strict;
 use warnings;
-use vars qw($VERSION $UP);
+use vars qw($UP);
 use base qw(Sys::Info::Driver::Unknown::Device::CPU::Env);
 
-$VERSION = '0.78';
-
 BEGIN {
     local $SIG{__DIE__};
     local $@;
@@ -23,7 +22,7 @@ sub identify {
     my $self = shift;
     $self->{META_DATA} ||= [
         !$UP ? $self->SUPER::identify(@_) : map {{
-            processor_id                 => $_->id, #cpu id 0,1,2,3...
+            processor_id                 => $_->id, # cpu id 0,1,2,3...
             data_width                   => undef,
             address_width                => undef,
             bus_speed                    => undef,
@@ -46,9 +45,17 @@ sub identify {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-Sys::Info::Driver::Unknown::Device::CPU - Compatibility layer for unsupported platforms
+Sys::Info::Driver::Unknown::Device::CPU
+
+=head1 VERSION
+
+version 0.79
 
 =head1 SYNOPSIS
 
@@ -56,12 +63,13 @@ See L<Sys::Info::Device::CPU>.
 
 =head1 DESCRIPTION
 
-This document describes version C<0.78> of C<Sys::Info::Driver::Unknown::Device::CPU>
-released on C<17 April 2011>.
-
 L<Unix::Processors> is recommended for
 unsupported platforms.
 
+=head1 NAME
+
+Sys::Info::Driver::Unknown::Device::CPU - Compatibility layer for unsupported platforms
+
 =head1 METHODS
 
 =head2 identify
@@ -82,16 +90,13 @@ L<Sys::Info>, L<Sys::Info::CPU>, L<Unix::Processors>.
 
 =head1 AUTHOR
 
-Burak Gursoy <burak@cpan.org>.
+Burak Gursoy <burak@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 - 2011 Burak Gursoy. All rights reserved.
+This software is copyright (c) 2006 by Burak Gursoy.
 
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.12.3 or, 
-at your option, any later version of Perl 5 you may have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
